@@ -3,7 +3,7 @@ import functools
 import inspect
 from abc import ABC, ABCMeta
 from dataclasses import dataclass
-from typing import Any, Awaitable, Callable, ClassVar, List, Optional, Type, Union
+from typing import Any, Awaitable, Callable, ClassVar, List, Optional, Set, Type, Union
 
 from aiogram import F, types
 from aiogram.dispatcher.router import Router
@@ -15,6 +15,8 @@ SubmitCallback = Optional[Callable[..., Any]]
 FormFilter = Union[MagicFilter, Callable[..., Awaitable[Any]]]
 Markup = Union[types.ReplyKeyboardMarkup, types.InlineKeyboardMarkup]
 
+REMOVE_MARKUP = types.ReplyKeyboardRemove(remove_keyboard=True)
+
 
 class FormState(StatesGroup):
     waiting_field_value = State()
@@ -94,6 +96,8 @@ class Form(ABC, metaclass=FormMeta):
 
     __submit_callback: SubmitCallback = None
 
+    __registered_forms: Set[Type["Form"]] = set()
+
     @classmethod
     def submit(cls):
         def decorator(submit_callback: SubmitCallback):
@@ -178,10 +182,10 @@ class Form(ABC, metaclass=FormMeta):
         await state_ctx.bot.send_message(
             state_ctx.key.chat_id,
             first_field.info.enter_message_text,  # type: ignore
-            reply_markup=first_field.info.reply_markup,  # type: ignore
+            reply_markup=first_field.info.reply_markup or REMOVE_MARKUP,  # type: ignore
         )
 
-        if getattr(cls, "__registered", False):
+        if cls in Form.__registered_forms:
             return
 
         router.message.register(
@@ -190,7 +194,7 @@ class Form(ABC, metaclass=FormMeta):
             cls.__current_field_filter,
         )
 
-        cls.__registered = True
+        Form.__registered_forms.add(cls)
 
     @classmethod
     async def __resolve_callback(
